<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Man\Controllers;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class RelVendasItensCanc {
    protected $relatorioService;
    protected $birtReport;

    public function __construct (ReportService $reportService, Services\Relatorio $relatorioService, Utilities\Util $utilService, BirtReport $birtReport) {
        $this->reportService = $reportService;
        $this->relatorioService = $relatorioService;
        $this->utilService = $utilService;
        $this->birtReport = $birtReport;
    }

    public function geraRelatorio(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $conditions = $this->utilService->getParamsAsArray($request);
        if($row['__report_name'] == 'vendaitemcancperiodo') {
            $parameterMapping = array(
                "CDFILIAL" => "CDFILIAL",
                "CDCAIXA" => "CDCAIXA",
                "TCDCAIXA" => "TCDCAIXA",
                "NRORG" => "NRORG",
                "DTVENDAINI" => "DTVENDAINI",
                "DTVENDAFIN" => "DTVENDAFIN",
                "CDCLIENTE" => "CDCLIENTE",
                "TCDCLIENTE" => "TCDCLIENTE",
                "CDCONSUMIDOR" => "CDCONSUMIDOR",
                "TCDCONSUMIDOR" => "TCDCONSUMIDOR",
                "CDVENDEDOR" => "CDVENDEDOR",
                "TCDVENDEDOR" => "TCDVENDEDOR",
                "CDPICTPROD" => "CDPICTPROD"
            );

            try{
                if(is_array($row['CDFILIAL']))
                    $row['CDFILIAL'] = implode(',', $row['CDFILIAL']);   
                $row['DTVENDAINI'] = $row['DTENTRVENDA']['start'];
                $row['DTVENDAFIN'] = $row['DTENTRVENDA']['end'];
                if(array_key_exists('CDCAIXA', $conditions) && is_array($row['CDCAIXA']))
                    $row['CDCAIXA'] = implode(',', $row['CDCAIXA']);
                if(array_key_exists('CDCLIENTE', $conditions) && is_array($row['CDCLIENTE']))    
                    $row['CDCLIENTE'] = implode(',', $row['CLIENFILIAL']);
                if(array_key_exists('CDCONSUMIDOR', $conditions) && is_array($row['CDCONSUMIDOR']))       
                    $row['CDCONSUMIDOR'] = implode(',', $row['CLIENTECONSUMIDOR']);
                if(array_key_exists('CDVENDEDOR', $conditions) && is_array($row['CDVENDEDOR']))      
                $row['CDVENDEDOR'] = implode(',', $row['CDVENDEDOR']);
                $dadosParaRelatorio = $this->relatorioService->buildParametersByRelatorio($row, $parameterMapping);
                $reportName = $dadosParaRelatorio['ReportName'];
                $parametersRow = $dadosParaRelatorio['ParametersRow'];

                $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow);
                // $birtURL = $this->birtReport->createRemoteReport($request, $response);
                $response->addDataset(new DataSet('URL',array($birtURL)));
            } catch (\Exception $e) {
                $response->setError(new Error($e->getMessage() , 500));
            }
        } else {
            $response->setError(new Error('Erro ao encontrar o relatório', 500));
            $chamaRelatorio = false;
        }
    }
}